@@ -1,12 +1,16 @@
 from eda_report.cli import process_cli_args
 from eda_report.document import ReportDocument
 
-__version__ = '1.3.1'
+__version__ = "1.3.2"
 
 
-def get_word_report(data, *, title='Exploratory Data Analysis Report',
-                    graph_color='orangered',
-                    output_filename='eda-report.docx'):
+def get_word_report(
+    data,
+    *,
+    title="Exploratory Data Analysis Report",
+    graph_color="orangered",
+    output_filename="eda-report.docx"
+):
     """Analyses the input data, and generates a report in *.docx* format.
 
     This is simply a wrapper around the
@@ -29,8 +33,13 @@ def get_word_report(data, *, title='Exploratory Data Analysis Report',
     .. _`list of named colors`:
         https://matplotlib.org/stable/gallery/color/named_colors.html
     """
-    ReportDocument(data, title=title, graph_color=graph_color,
-                   output_filename=output_filename)
+    # Generate a report using the supplied parameters
+    ReportDocument(
+        data,
+        title=title,
+        graph_color=graph_color,
+        output_filename=output_filename,
+    )
 
 
 def run_from_cli():
@@ -45,6 +54,12 @@ def run_from_cli():
     :func:`~eda_report.cli.process_cli_args` function, and then supplied to the
     :func:`~eda_report.get_word_report` function to generate the report.
     """
+    # Collect parameters from the command line interface
     args = process_cli_args()
-    get_word_report(args.infile, title=args.title, graph_color=args.color,
-                    output_filename=args.outfile)
+    # Generate a report
+    get_word_report(
+        args.infile,
+        title=args.title,
+        graph_color=args.color,
+        output_filename=args.outfile,
+    )
