@@ -3,17 +3,16 @@ from io import BytesIO
 import matplotlib
 from matplotlib.figure import Figure
 
-
 # Matplotlib configuration
-matplotlib.rcParams['figure.dpi'] = 150  # resolution (dots per inch)
-matplotlib.rcParams['figure.autolayout'] = True  # tight layout
-matplotlib.rcParams['savefig.transparent'] = False  # transparent background
-matplotlib.rcParams['savefig.edgecolor'] = 'k'  # black frame
-matplotlib.rcParams['savefig.facecolor'] = 'w'  # white background
-matplotlib.rcParams['font.family'] = 'serif'
-matplotlib.rcParams['axes.spines.top'] = False  # remove top spine
-matplotlib.rcParams['axes.spines.right'] = False  # remove left spine
-matplotlib.use('agg')  # use non-interactive matplotlib back-end
+matplotlib.rcParams["figure.dpi"] = 150  # resolution (dots per inch)
+matplotlib.rcParams["figure.autolayout"] = True  # tight layout
+matplotlib.rcParams["savefig.transparent"] = False
+matplotlib.rcParams["savefig.edgecolor"] = "k"  # black frame
+matplotlib.rcParams["savefig.facecolor"] = "w"  # white background
+matplotlib.rcParams["font.family"] = "serif"
+matplotlib.rcParams["axes.spines.top"] = False  # remove top spine
+matplotlib.rcParams["axes.spines.right"] = False  # remove left spine
+matplotlib.use("agg")  # use non-interactive matplotlib back-end
 
 
 Fig = Figure
@@ -28,11 +27,12 @@ def savefig(figure):
     saved as *attributes* in ``io.BytesIO`` objects, allowing convenient and
     rapid in-memory access.
 
-    :param figure: A matplotlib figure with plotted axes.
+    :param figure: A *matplotlib figure* with plotted axes.
     :type figure: ``matplotlib.figure.Figure``
     :return: A file-like object with the figure's contents.
     :rtype: ``io.BytesIo``
     """
     graph = BytesIO()
     figure.savefig(graph)
+
     return graph
